"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _shopify = require("./shopify");

var _apollo = _interopRequireWildcard(require("./apollo"));

var _authentication = require("./authentication");

var _checkout = _interopRequireWildcard(require("./checkout"));

var _provider = _interopRequireWildcard(require("./context/provider"));

var _database = _interopRequireWildcard(require("./database"));

var _mutations = require("./functions/mutations");

var _context = require("./functions/context");

var HeadlessFramework = {
  Apollo: {
    Provider: _apollo["default"],
    createApolloClient: _apollo.createApolloClient
  },
  Auth: {
    Provider: _authentication.AuthProvider,
    Context: _authentication.AuthContext,
    Roles: _authentication.AuthRoles,
    needsEmailVerification: _authentication.needsEmailVerification
  },
  Checkout: {
    Client: _checkout.Checkout,
    Context: _checkout.CheckoutContext,
    Provider: _checkout["default"]
  },
  ShopifyCustomer: {
    Client: _shopify.ShopifyCustomer,
    Context: _shopify.ShopifyCustomerContext,
    Provider: _shopify.ShopifyCustomerProvider
  },
  Context: _provider.NextContext,
  Database: {
    Context: _database.DatabaseContext,
    Provider: _database["default"]
  },
  Provider: _provider["default"],
  Shopify: {
    Helpers: {
      formatLink: _shopify.formatLink,
      formatTitle: _shopify.formatTitle,
      formatURL: _shopify.formatURL
    }
  },
  Functions: {
    Context: _context.FunctionsContext,
    Mutations: {
      CUSTOMER_UPDATE: _mutations.CUSTOMER_UPDATE
    }
  }
};
var _default = HeadlessFramework;
exports["default"] = _default;